==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/ApiregistrationV1beta1ServiceReferenceFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ApiregistrationV1beta1ServiceReferenceFluentImpl<A extends ApiregistrationV1beta1ServiceReferenceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements ApiregistrationV1beta1ServiceReferenceFluent<A>{

    private String name;
    private String namespace;

    public ApiregistrationV1beta1ServiceReferenceFluentImpl(){
    }
    public ApiregistrationV1beta1ServiceReferenceFluentImpl(ApiregistrationV1beta1ServiceReference instance){
            this.withName(instance.getName());

            this.withNamespace(instance.getNamespace());

    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public String getNamespace(){
            return this.namespace;
    }

    public A withNamespace(String namespace){
            this.namespace=namespace; return (A) this;
    }

    public Boolean hasNamespace(){
            return this.namespace != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ApiregistrationV1beta1ServiceReferenceFluentImpl that = (ApiregistrationV1beta1ServiceReferenceFluentImpl) o;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/ApiregistrationV1beta1ServiceReferenceFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ApiregistrationV1beta1ServiceReferenceFluentImpl<A extends ApiregistrationV1beta1ServiceReferenceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements ApiregistrationV1beta1ServiceReferenceFluent<A>{

    private String name;
    private String namespace;

    public ApiregistrationV1beta1ServiceReferenceFluentImpl(){
    }
    public ApiregistrationV1beta1ServiceReferenceFluentImpl(ApiregistrationV1beta1ServiceReference instance){
            this.withName(instance.getName());

            this.withNamespace(instance.getNamespace());

    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public A withNewName(String arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1){
            return (A)withName(new String(arg1));
    }

    public String getNamespace(){
            return this.namespace;
    }

    public A withNamespace(String namespace){
            this.namespace=namespace; return (A) this;
    }

    public Boolean hasNamespace(){
            return this.namespace != null;
    }

    public A withNewNamespace(String arg1){
            return (A)withNamespace(new String(arg1));
    }

    public A withNewNamespace(StringBuilder arg1){
            return (A)withNamespace(new String(arg1));
    }

    public A withNewNamespace(StringBuffer arg1){
            return (A)withNamespace(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ApiregistrationV1beta1ServiceReferenceFluentImpl that = (ApiregistrationV1beta1ServiceReferenceFluentImpl) o;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
            return true;
    }




}
